QuGrad
======

.. include:: ../README.md
   :parser: myst_parser.sphinx_
   :start-after: # QuGrad


.. toctree::
   :hidden:
   :titlesonly:

   user_guide/index
   reference/index
   developer_reference
   ChangeLog.md.rst
   citation/include_citation
   include_license
   GitHub <https://github.com/Christopher-K-Long/QuGrad>
   PyPI <https://pypi.org/project/QuGrad>